@@ -394,14 +394,15 @@ feed_add_xml_attributes (nodePtr node, xmlNodePtr feedNode)
 	xmlNewTextChild (feedNode, NULL, "feedId", node_get_id (node));
 	xmlNewTextChild (feedNode, NULL, "feedTitle", node_get_title (node));
 
-	if (feed->description)
-		xmlNewTextChild (feedNode, NULL, "feedDescription", feed->description);
-
 	if (feed_get_image_url (feed))
 		xmlNewTextChild (feedNode, NULL, "feedImage", feed_get_image_url (feed));
 
 	// FIXME: move subscription stuff to subscription.c
 	if (node->subscription) {
+		tmp = (gchar *)metadata_list_get (node->subscription->metadata, "description");
+		if (tmp)
+			xmlNewTextChild (feedNode, NULL, "feedDescription", tmp);
+			
 		xmlNewTextChild (feedNode, NULL, "feedSource", subscription_get_source (node->subscription));
 		xmlNewTextChild (feedNode, NULL, "feedOrigSource", subscription_get_orig_source (node->subscription));
 
@@ -484,15 +485,6 @@ feedHandlerPtr feed_get_fhp(feedPtr feed) {
 	return feed->fhp;
 }
 
-const gchar * feed_get_description(feedPtr feed) { return feed->description; }
-void feed_set_description(feedPtr fp, const gchar *description) {
-	g_free(fp->description);
-	if(description != NULL)
-		fp->description = g_strdup(description);
-	else
-		fp->description = NULL;
-}
-
 const gchar * feed_get_html_url(feedPtr feed) { return feed->htmlUrl; };
 void feed_set_html_url(feedPtr feed, const gchar *base, const gchar *htmlUrl) {
 	g_free(feed->htmlUrl);
@@ -536,7 +528,6 @@ feed_free (nodePtr node) {
 		g_string_free(feed->parseErrors, TRUE);
 	g_free(feed->htmlUrl);
 	g_free(feed->imageUrl);
-	g_free(feed->description);
 	g_free(feed);
 }
 
@@ -549,7 +540,6 @@ feed_process_update_result (nodePtr node, const struct updateResult * const resu
 	feedPtr			feed = (feedPtr)node->data;
 	subscriptionPtr		subscription = (subscriptionPtr)node->subscription;
 	gchar			*old_source;
-	gint			old_update_interval;
 
 	debug_enter ("feed_process_update_result");
 	
@@ -559,8 +549,7 @@ feed_process_update_result (nodePtr node, const struct updateResult * const resu
 	
 	if (result->data) {
 		/* we save all properties that should not be overwritten in all cases */
-		old_update_interval = subscription_get_update_interval (subscription);
-		old_source = g_strdup (subscription_get_source (subscription));
+		old_source = g_strdup (subscription_get_source (subscription));	// FIXME: stupid concept?
 
 		/* parse the new downloaded feed into feed and itemSet */
 		ctxt = feed_create_parser_ctxt ();
@@ -582,10 +571,18 @@ feed_process_update_result (nodePtr node, const struct updateResult * const resu
 			                                       "XML Parser Output:<br /><div class='xmlparseroutput'>"));
 			g_string_append (feed->parseErrors, "</div>");
 		} else {
+			itemSetPtr	itemSet;
+			guint		newCount;
+			
 			node->available = TRUE;
 			
 			/* merge the resulting items into the node's item set */
-			node_merge_items (node, ctxt->items);
+			itemSet = node_get_itemset (node);
+			newCount = itemset_merge_items (itemSet, ctxt->items, ctxt->feed->valid);
+			itemlist_merge_itemset (itemSet);
+			itemset_free (itemSet);
+
+			feedlist_node_was_updated (node, newCount);
 			
 			/* restore user defined properties if necessary */
 			if (flags & FEED_REQ_RESET_TITLE)
@@ -594,10 +591,17 @@ feed_process_update_result (nodePtr node, const struct updateResult * const resu
 			if (!(flags & FEED_REQ_AUTO_DISCOVER))
 				subscription_set_source (subscription, old_source);
 
-			if (flags & FEED_REQ_RESET_UPDATE_INT)
-				subscription_set_update_interval (subscription, subscription_get_default_update_interval(subscription));
-			else
-				subscription_set_update_interval (subscription, old_update_interval);
+			if (flags & FEED_REQ_RESET_UPDATE_INT) {
+				/* The following check is to prevent the rare case
+				   that a high-frequency/volume feed provides a feed-
+				   specific update interval that is lower than the
+				   users preferred update interval. This e.g. 1min
+				   updates might be bad for laptop users... */
+				if (subscription_get_default_update_interval (subscription) < conf_get_int_value (DEFAULT_UPDATE_INTERVAL))
+					subscription_set_update_interval (subscription, conf_get_int_value (DEFAULT_UPDATE_INTERVAL));
+				else
+					subscription_set_update_interval (subscription, subscription_get_default_update_interval(subscription));
+			}
 			
 			if (flags > 0)
 				db_subscription_update (subscription);
